import { AttachmentType, Carrier, CarrierService, ExtraCarrierService, ISOCountry, ISODate, ParcelStatus, RegistrationNumberType, ULID, UnitOfMeasurement } from './common';
export interface ISender {
    name: string;
    street: string;
    city: string;
    postal: string;
    country: ISOCountry;
    houseNumber?: string;
    phone?: string;
    email?: string;
}
export interface IReceiver {
    name: string;
    company?: string;
    street: string;
    city: string;
    postal: string;
    country: ISOCountry;
    houseNumber?: string;
    phone?: string;
    email?: string;
}
export interface IParcelStatus {
    status: ParcelStatus;
    dateOfChange: ISODate;
    carrierStatus: string;
    carrierStatusCode?: string;
}
export interface IParcel {
    identifier?: string;
    parcelId: string;
    externalParcelId: string;
    weight?: number;
    length?: number;
    width?: number;
    height?: number;
    value?: number;
    status: ParcelStatus;
    statusUpdated: ISODate;
    statuses?: IParcelStatus[];
    trackingId?: string;
    barcodeTrackingId?: string;
    trackingUrl?: string;
}
export interface IAddress {
    city: string;
    postal: string;
    country: ISOCountry;
    street: string;
    houseNumber?: string;
}
export interface IContact {
    name: string;
    phone: string;
    company?: string;
    email?: string;
}
export interface IImporterDetail {
    address: IAddress;
    contact: IContact;
}
export interface IRegistrationNumber {
    typeCode: RegistrationNumberType;
    number: string;
    issuerCountryCode?: ISOCountry;
}
export interface ICN22Info {
    description?: string;
    currency?: string;
    EAN?: string;
    HSCode: string;
    exportReason: string;
    originCountry?: string;
    exportDate?: ISODate;
    deliveryCost?: number;
}
export interface ICarrierOption {
    name: string;
    value: string;
}
export interface ICOD {
    value: number;
    currency: string;
    transactionId: string;
}
export interface ICustomsDeclarable {
    value?: string;
}
export interface IAdditionalInformation {
    unitOfMeasurement?: UnitOfMeasurement;
    pickupPhone?: string;
    registrationNumbers?: IRegistrationNumber[];
    carrierOptions?: ICarrierOption[];
    CN22Info?: ICN22Info;
    addressId?: string;
    dispatchId?: string;
    COD?: ICOD;
    useShippypro?: boolean;
    unitOfMeasurment?: UnitOfMeasurement;
    verbalDeliveryConfirmationNumber?: string;
    signatureReleaseName?: string;
    specialPickupInfo?: string;
    dangerousGoodsIds?: string[];
    importerDetails?: IImporterDetail;
    customsDeclarable?: ICustomsDeclarable;
    attachmentType?: AttachmentType;
    attachment?: string;
    externalCarrierService?: string;
    externalCarrierPickupPoint?: string;
    carrierNote?: string;
}
export interface IOrder {
    orderId: ULID;
    externalOrderId: string;
    carrierId: Carrier;
    customerId: string;
    sender: ISender;
    receiver: IReceiver;
    parcels: IParcel[];
    carrierService?: CarrierService;
    additionalInformation?: IAdditionalInformation;
    extraCarrierServices?: ExtraCarrierService[];
    labelUrl?: string;
    cancelled: boolean;
    cancelledDate?: ISODate;
    createdAt: ISODate;
}
//# sourceMappingURL=order.interface.d.ts.map