"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RabbitMQService = void 0;
const messageDefinitions_1 = require("../../services/rabbitmq/messages/messageDefinitions");
const exceptions_1 = require("./exceptions");
const messages_1 = require("./messages");
class RabbitMQService {
    constructor(amqpConnection, options) {
        this.amqpConnection = amqpConnection;
        this.options = options;
    }
    sendCancelOrderMessage(message) {
        this.publishMessage((0, messageDefinitions_1.getCancelOrderMessageDefinition)(), message);
    }
    sendHealthStatusMessage(message) {
        this.publishMessage((0, messageDefinitions_1.getHealthStatusMessageDefinition)(), message);
    }
    sendHealthCheckMessage() {
        this.publishMessage((0, messageDefinitions_1.getHealthCheckMessageDefinition)(), null);
    }
    sendCreateOrderMessage(message) {
        this.publishMessage((0, messageDefinitions_1.getNewOrderMessageDefinition)(message.carrierId), message);
    }
    sendSaveOrderMessage(message) {
        this.publishMessage((0, messageDefinitions_1.getSaveOrderMessageDefinition)(), message);
    }
    sendUpdateOrderMessage(message) {
        this.publishMessage((0, messages_1.getUpdateOrderMessageDefinition)(), message);
    }
    sendTrackingMessage(message) {
        this.publishMessage((0, messages_1.getTrackingMessageDefinition)(message.carrierId), message);
    }
    sendTrackingRequeueMessage(message) {
        this.publishMessage((0, messages_1.getTrackingRequeueMessageDefinition)(message.carrierId), message);
    }
    sendPrintLabelMessage(message) {
        this.publishMessage((0, messages_1.getPrintLabelMessageDefinition)(), message);
    }
    sendOutputOrderStatusMessage(message) {
        this.publishMessage((0, messages_1.getOutputOrderStatusMessageDefinition)(), message);
    }
    sendOutputErrorMessage(message) {
        this.publishMessage((0, messages_1.getOutputOrderStatusMessageDefinition)(), message);
    }
    getOrderById(message) {
        return this.publishMessageRpc((0, messages_1.getOrderGetByIdMessageDefinition)(), message);
    }
    async publishMessageRpc(messageDefinition, message) {
        var _a;
        const { exchange, routingKey } = messageDefinition;
        const requestOptions = {
            exchange,
            routingKey,
            payload: message,
            timeout: (_a = this.options) === null || _a === void 0 ? void 0 : _a.defaultRpcTimeoutMs,
        };
        try {
            const response = await this.amqpConnection.request(requestOptions);
            if (response.error)
                throw new exceptions_1.RabbitMqResponseErrorException(response.error, exchange, routingKey);
            if (response.data === undefined)
                throw new exceptions_1.RabbitMqResponseErrorException('Rabbit MQ response is undefined and error is not set', exchange, routingKey);
            return response.data;
        }
        catch (e) {
            const error = e;
            if (error === null || error === void 0 ? void 0 : error.message.startsWith('Failed to receive response within timeout'))
                throw new exceptions_1.RabbitMqResponseTimeoutException(`Rabbit MQ timeout exception after ${requestOptions.timeout} ms`, exchange, routingKey);
            throw e;
        }
    }
    publishMessage(messageDefinition, message) {
        const { exchange, routingKey, pattern } = messageDefinition;
        const envelope = {
            pattern,
            data: message,
        };
        this.amqpConnection.publish(exchange, routingKey, envelope);
    }
}
exports.RabbitMQService = RabbitMQService;
//# sourceMappingURL=rabbitmq.service.js.map